@@ -5,7 +5,7 @@ from abc import ABC, abstractmethod
 from dataclasses import dataclass
 from datetime import timedelta
 from enum import Enum, auto
-from typing import FrozenSet, List, NoReturn, Optional, Union
+from typing import Final, FrozenSet, List, NoReturn, Optional, Union
 
 from lucupy.helpers import flatten
 
@@ -17,6 +17,9 @@ from .site import Site
 from ..types import ZeroTime
 
 
+ROOT_GROUP_ID: Final[str] = 'root'
+
+
 @dataclass
 class Group(ABC):
     """This is the base implementation of AND / OR Groups.
